@@ -3,8 +3,12 @@
 #############################################
 # que delete script
 #############################################
+
+# global.cof load
 LANG=C;export LANG
 SCRIPT_DIR=`dirname $0`
+. ${SCRIPT_DIR}/../global.conf
+
 LOG=${SCRIPT_DIR}/log/delete_que_`date +%Y%m%d`
 
 ## root dir load
@@ -12,12 +16,8 @@ LOG=${SCRIPT_DIR}/log/delete_que_`date +%Y%m%d`
 
 QUE_DIR=${ROOT}/que
 
-#status que
-find ${QUE_DIR}/status -type f -mtime +1 >> ${LOG} 2>&1
-find ${QUE_DIR}/status -type f -mtime +1 | xargs rm -f  >> ${LOG} 2>&1
-
-#error que
-find ${QUE_DIR}/error -type f -mtime +30 >> ${LOG} 2>&1
-find ${QUE_DIR}/error -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1
+#daemon_error que
+find ${QUE_DIR}/daemon_error -type f -mtime +30 >> ${LOG} 2>&1
+find ${QUE_DIR}/daemon_error -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1
 
 exit 0
